Handbook - Nervous System Neuronal Support Cells
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

NERVOUS SYSTEM NEURONAL SUPPORT CELLS Click pictures for new window with figure and legend, click again for high resolution image
1 Overview The adult C. elegans hermaphrodite nervous system has 56 support cells that fall into three categories: 24 sheath cells, 26 socket cells, and 6 GLR cells (NeuroTABLE 2). The six GLR cells are located on the inner surface of the NR and are closely associated with the development of the arms of the head muscles. Additionally, unlike neurons and sheath and socket cells, GLRs are mesodermally derived (see Muscle system - GLR cells). The remaining support cells and their related sensory neurons form the sensory organs called sensilla mainly located in the head and tail of the worm. NeuroTABLE 2: Neuronal support cells.
2 Sensillum Structure A sensillum is a simple epithelial sense organ composed of dendrites of one or more bipolar sensory neurons surrounded by a channel formed by a single sheath cell and one or more socket cells (NeuroFIG 22) (Bird and Bird, 1991; Doroquez et al., 2014). At the extreme end of its process, the socket cell forms a small, ring-like tissue that surrounds the distal ends of the cilia of the sensory dendrites, whereas the extreme distal portion of the sheath cell envelops the lumen of the sensillar pouch immediately posterior to the socket cell. The socket and sheath-cell processes are sealed to each other by electron-dense adherens junctions. Less robust adherens junctions also connect the socket cell to the hypodermis. Virtually all of the sensilla are concentrated in the head and the tail in C. elegans. NeuroFIG 22: Positions of left-side C. elegans sensilla. A similar set of sensilla is found on the right side. A. Twenty of these sensilla are located in the head, with their endings in the lips. Head sensilla include amphid and OLL sensilla on the lateral sides of the lips, CEP and OLQ sensilla on the dorsal and ventral quadrant lips, and IL sensilla on the medial side of all six lips. The somata of the cells that comprise the IL, OLL, and OLQ sensilla as well as CEPso and Amso are clustered around the anterior isthmus and anterior bulb of the pharynx. The remaining CEP sensillar cells lie close to the NR, whereas amphid neurons and Amsh cells are posterior to the nerve ring. The anterior dendrites of these sensillar cells run to the lips in distinct nerve bundles. Within the lips, they end in visible papillae (IL) or pockets (amphid), or they make cuticular endings (CEP, OLQ, and OLL) that are not visible from the surface (see NeuroFIG 4A). All of their axons project to the NR (not shown). Only CEPsh cells are shown on the right side. B. Three pairs of sensilla are located in the region from the posterior head to tail. ADE sensillar cells are located around the posterior bulb of the pharynx. (Only the ADE neuron is shown.) Cells of PDE sensilla are located halfway between the vulva and anus. (Only the PDE neuron is shown.) Cells of phasmid sensilla are located in the tail (only the PHA neuron is shown). (Small blue fingers) Location of each sensillar cilium wrapped by the sheath and socket cell processes (not shown). 2.1 Cilium Some sensory neuron dendrites form sensory cilia (nonmotile, microtubule-rich extensions specialized as receptors for diverse sensory modalities) at their termini. Generally, the cilia contain receptor molecules and various signal transduction components. Therefore, it is assumed that they are the primary sites of transduction at which environmental stimuli are converted into receptor potentials. The common structure of a cilium in C. elegans is a finger-like process containing nine outer doublet MTs arranged in a circle (9 + 0 axoneme arrangement) around two to six inner, singlet MTs (NeuroFIG 23; NeuroTABLE 3) (Lewis and Hodgkin, 1977; Albert et al., 1981; Perkins et al., 1986). The nine doublet MTs originate from the basal body, which is a modified centriole found at the base of the cilium. The assembly, maintenance, and function of cilia are managed through MT-based intraflagellar transport (IFT), which moves cargo including IFT particles to and from the distal tip. IFT uses canonical, anterograde, heterotrimeric kinesin II and retrograde, cytoplasmic dynein (CHE-3) motors (Barr, 2005; Blacque et al., 2005; Inglis et al., 2007). NeuroFIG 23: Ultrastructure of amphid cilia. A. Ciliated endings of eight amphidial neurons. In this example, many cilia are sectioned through their “middle segment,” transverse section. Each cilium contains 9 MT doublets (d), which are composed of A sub-fibers (a) with 13 protofilaments and B subfibers (b) with 11 protofilaments. Each cilium also possesses a variable number (1–6) of inner singlet 11p MTs (s). Hook (h) structures are seen as the B subfibers end near the end of the middle segment. Distal to the ends of B subfibers, nine 13p MTs are seen around the periphery of the process with a smaller number of 11p singlets inside. Magnification, 300,000x, TEM image. (Reprinted, with permission, from Chalfie and Thomson, 1982. ©The Rockefeller University Press.) B. TEM of the left amphid channel, longitudinal section. (Same section as in NeuroFIG 35B, magnified.) Amphid cilia exposed to the outside are clustered within the amphid channel (thin arrow). The fingers of the AFD neuron embedded within the sheath cell are seen to the right of the channel (arrowheads). The arrow points to the socket cell, which surrounds the distal portion of the channel. The levels of sections in panels C–G are shown with straight blue lines in B. Anterior is at the top of the panel. Bar, 1 μm. C–G. Transverse TEM sections through the amphid channel at various levels. Bar, 0.5 μm. (Top panels) A single cilium magnified further. (Based on Perkins et al., 1986.) C. Section through the distal segments, showing ten channel cilia about 3 μm from the tip of the lips. At this level, each cilium contains only the 13p A subfibers, which continue into the distal segment, and several 11p singlet MTs. The cuticle lines the surface of the socket channel (arrow). (Arrowhead) Self-junction of the socket cell (Perkins et al., 1986). D. Section through the middle segments, about 5.5 μm from the tip of the lips. Nine doublet MTs (with both A and B subfibers) are attached to the membrane and two to seven smaller singlet MTs occupy the center of each cilium (five are seen in the top panel). No apical ring is seen yet. An electron-dense material lines the sheath channel surface and a scant matrix is seen inside this surface surrounding the cilia (arrow). Sheath-cell cytoplasm is filled with a filamentous scaffold (FS) around the channel. A sheath cell makes adherens junctions (arrowhead) to the socket cell (asterisk), which has moved peripherally by this level. E. Section through the transition zone, which is about 0.27 μm in diameter and 1 μm long in each cilium. Matrix (M) separates the cilia in the channel. Within each cilium, the nine doublets are drawn together by the apical ring and are attached to the cilium membrane by Y-shaped links. The seven singlets are aligned along the inner face of the apical ring and are also attached to it. These inner singlets also originate at the base of the transition zone. (Colored panel) Schematic rendition of the structure of the transition zone. (Mb) Cilium membrane; (AR) apical ring. F. Section through the transitional fibers (arrowheads, top panel), about 8 μm from the tip of the lips. Transitional fibers, which may contain a residue of the nematode centriole, join the ends of the doublets radially to the cell membrane. Instead of a distinct basal body, an amorphous root is seen in the center of the dendrite. G. Section posterior to the transitional fiber zone showing two dendrites. The left dendrite has an amorphous root and is filled with coated pits and vesicles (arrow) just proximal to the base of the cilium. The dendrite on the right is from a more proximal level behind the neuron-sheath junction. This dendrite contains a bundle of seven neurofilaments (arrowhead, top panel). The amorphous root, about 1 μm long, is seen in all channel cilia and the wing cilia. As it tapers out, a fascicle of 3–12 neurofilaments, which are a few micrometers long, becomes visible. There is no amorphous root in AFD dendrites. NeuroTABLE 3: Neuronal cilium structure. NA, not available. Table data compiled from unpublished data, Altun & Hall 2014; Ward et al., 1975; Ware et al., 1975; Perkins et al., 1986; Hall and Russell, 1991. 1Striated rootlets extend into the center of the ciliary transition zones. 2Cilium ends in alar cuticle. 3Cilium ends in pseudocoelom. 4Cilium ends wrapped in socket cell close to pseudocoelom. 5Cilium is not found in every animal. It ends in hypodermis in tail tip.6Short cilium. AJ: adherense junction. In C. elegans, normal cilia development takes place at around the midpoint of the threefold stage of embryogenesis. During ciliogenesis, one of the centrioles converts to a basal body by assembling a transition zone that serves as a docking site for IFT proteins and motors (Li et al., 2004). The basal body serves as a template for the formation of the axoneme, which projects out from the basal body in a bud-like structure covered by the cell membrane. The A and B tubules of the basal body microtubules grow into the axonemal shaft, generating the nine doublets. Within the transition zone, microtubules are anchored to the cell membrane by transitional fibers that are also believed to be involved in loading IFT motor cargo complexes onto the ciliary axoneme (Blacque et al., 2004; Bossinger and Bachmann, 2004). Precursors are incorporated into the ciliary structures at the distal tip after being carried by IFT motors and IFT particles. Two IFT kinesins, heterotrimeric kinesin-II and OSM-3, work redundantly to build the proximal and middle segments of the axonemes, whereas more distally, OSM-3 alone is required to extend the distal singlets (Ou et al., 2005; Evans et al., 2006). Between 650 and 770 minutes after the first cleavage, the average length of the cilia is 3–5 μm (Fujiwara et al., 1999). By 770–800 minutes, cilia have reached an average length of 5–7 μm and, by the time of hatching, some of the cilia have grown even longer. Even if normal cilia formation does not take place during embryogenesis, some C. elegans neurons retain the ability to extend cilia in later stages, including the adult stage (Fujiwara et al., 1999). Hermaphrodites have 61 ciliated neurons, and all except three (AQR, PQR, and PVR) are members of bilateral pairs (Ward et al., 1975; White et al., 1986; Hall and Russell, 1991). Twenty six of these 61 neurons have endings that are exposed to the environment and are located in the head amphid and inner labial sensilla and the tail phasmid sensilla. The male possesses an additional 52 ciliated neurons; all except two (HOA and HOB) are also arranged as left–right pairs. In wild-type animals, hydrophobic fluorescent dyes such as fluorescein isothiocyanate (FITC) and the carbocyanine dyes DiO and DiI penetrate into eight classes of ciliated neurons of the amphid and phasmid (Hedgecock et al., 1985; Starich et al., 1995). Mutations that affect cilium structure and hence prevent dye uptake (dye-filling mutant; dyf) have been identified. Tendyf genes were found to affect structure of all neuronal cilia and encode for IFT particle proteins or transcription factors (Perkins et al., 1986; Swoboda et al., 2000; Qin et al., 2001; Sloboda, 2002). Additional dyf mutations are specific to subsets of ciliated neurons and may involve proteins that have a role in refining the structure of specific cilia for certain functions after the general cilium structure has been built (Barr, 2005). 2.2 Socket and Sheath Cells Sensillar endings are enclosed within a protected environment by sheath and socket cells, which are specialized interfacial epithelial cells derived from the AB lineage (NeuroFIG 24; NeuroTABLE 2). These are considered to be glial cells, because they are closely associated with the ciliated endings of the sensory receptors of specific sensilla in C. elegans (Ward et al., 1975.) Sheath and socket cells lack synaptic connections or GJs to neighboring neurons, but they are closely related to neurons by lineage (Sulston et al., 1983). In early development, a hypodermal or seam stem cell such as T and its daughters may have the role of socket in forming a sensory opening before the birth of the true socket cell (Sulston and Horvitz, 1977; Sulston et al., 1983). NeuroFIG 24: Anatomy of amphid sensillum. Shown are four representative examples of channel and wing cilia. A. Structure of the amphid opening, longitudinally. Amphid channel (Ch) is lined by the cuticle in the distal (socket) part and an electron-dense lining supported by a scaffold of cytoskeletal filaments (Fs) in the anterior sheath part. The socket cell is connected to the hypodermis and the sheath cell by adherens junctions (aj). Adherens junctions are also seen between the dendrites and sheath cell (neuron-sheath junction) proximally to the level where the dendrites enter the channel. A large Golgi apparatus located at the base of the sheath-cell process (left) gives rise to matrix-filled vesicles bound toward the channel. Mitochondria (not shown) are also present in this region. (Modified, with permission, from Perkins et al., 1986. ©Elsevier.) B. Illustration of invagination of the sheath-cell cytoplasm by amphid dendrites (long gray arrows), longitudinally. The process of the AFD neuron stays embedded within the sheath cell, whereas all others enter the matrix-filled amphid channel. The cilia of the wing cells penetrate back into the sheath cell, whereas the eight channel cilia are exposed to the outside through the cuticle pore. C. Illustration of longitudinal microtubule (MT) structure of amphid cilia. Each cilium is about 7.5 μm long in adult C. elegans and is composed of three segments: the proximal, middle, and distal segment. MTs project distally from the proximal segment (the transition zone). The nine doublet (d) MTs and inner singlets (s) continue through the middle zone. The distal zone contains some A fibers (not shown) and singlet MTs. The fan-like AWC cilium is an exception because the A fibers do not extend distally, and both the singlet and doublet MTs terminate at approximately the same level (Evans et al., 2006). D. TEM of amphid channel cilia. Transverse section through middle segments of cilia. The AWB and AWC cilia interrupt the electron-dense lining of the channel and the filamentous scaffold as they invaginate back into the sheath cell (Amsh). The doublet and singlet MTs in AWB and AWC fan out into these flattened processes. AWA cilium branches into several small fingers, each of which contains one or more of the original nine doublet MTs. Numerous AFD fingers (also called villi) are seen within the sheath cell around the single AFD cilium. Bar, 0.5 μm. (Image source: N2nose [MRC] 3731-19.) Unlike higher organisms, glia do not form myelin and are not required for neuronal survival in C. elegans. However, they have a role in neuronal development and function, as has been shown through ablation studies (Sulston et al., 1983; Shaham, 2006). Sheath cells regulate dendrite extension, and socket cells are involved in navigating sensory dendrites to specific sensory organs. In the absence of sheath cells, associated sensory dendrites fail to complete their extension, whereas when socket cells are missing, sensory dendrites of that sensillum infiltrate a different sensory organ (Sulston et al., 1983). In addition to regulating dendrite extension and organizing groups of dendrites, glia might also have roles in general axon guidance. During NR development in embryogenesis, inner labial sheaths are suggested to guide axons entering the NR neuropil from the anterior, whereas cephalic sheaths may guide axons entering the ring from the posterior (Wadsworth et al., 1996). In general, socket cell bodies tend to be smaller and lie closer to the sensilla than the sheath cells (NeuroFIG 22). Each cell extends one long, thin process along the terminal portions of the sheath and neuron processes that wraps around the dendritic tips, distal to the sheath endings. Socket cells are also more epithelial in nature; they connect to the hypodermis via adherens junctions and secrete cuticle that lines the external opening of some of the sensilla. Socket cells make a pore through which sensory dendrites may extend into the cuticle and, in some cases, to the animal’s exterior. Sheath-cell processes ensheath the ciliary endings of the dendrites proximally to the sockets. Cilia often traverse the sheath-cell cytoplasm in narrow membranous tubes to enter the sensillar channel within the sheath cell. The tubular lumen of the sheath cell comprises the proximal portion of the bipartite sensillar channel, and the hole of the socket ending comprises the distal part. Some sheath cells can be very large, particularly those for the amphids, each of which enclose 12 cilia. Some sheath cells, including the labial and cephalic sheaths, have lamella that project into the lumen of the sensillar channel. Amphid sheaths secrete a granular electron-dense material into the channel that surrounds the cilia (Ward et al., 1975; Bird and Bird, 1991). The sheath cells for smaller sensilla are less complex, but contain some of these features in less dramatic form, often including several small membrane lamellae and a few vesicles near the channel. 2.3 Accessory Neurons of Head Sensilla Some neurons are closely associated with head sensilla, although they are not truly part of them. All of these are either sensory neurons or suggested to have yet unknown sensory functions. Six of these, two URX and four URY neurons, travel within the labial nerves to the lips, although they do not end within the labial sensilla. URXL/R neurons have unciliated, small bulb-like endings between CEPshDL/R and AmshL/R. URYDL/R neurons terminate in a thin sheet-like structure close to the ILshDL/R and OLQshDL/R, whereas URYVL/R neurons terminate close to ILshVL/R and OLQshVL/R. Similarly, FLP and BAG neurons do not have specific socket and sheath cells assigned to them, although their processes travel within the lateral labial process bundles (see NeuroFIG 19). These ciliated neurons terminate close to the lip cuticle on each side. BAG endings make bag-shaped, swollen structures that wrap short projections from the hypodermis close to IL sensilla at each subventral side (NeuroFIG 25) (Ward et al., 1975; Perkins et al., 1986; White et al., 1986). FLP neurons terminate close to ILsoL/R, but they also send branches to the dorsal and ventral sides (NeuroFIG 10 and NeuroFIG 25) (Ward et al., 1975). NeuroFIG 25: Cilia morphology of the sensory neurons that terminate in the lips. (Based on Ward, 1973. For an expanded version see: Dendrites Poster) (Top panel) Illustrations of cilia. (Middle panel) Epifluorescent images of cilia (OLQ and IL1 are not shown). Although all chemosensory amphid cilia are similar in shape with one (ASE, ASG, ASH, ASI, ASJ, ASK) or two (ADF, ADL) slim, finger-like cylinders, each of the amphid wing cilia (AWA, AWB, AWC) has a unique shape (Ward et al., 1975; Ware et al., 1975). The AWC ilium spreads vertically into a large, wing-like sheet that fills up most of the lateral side of the sheath cell. AWA and AWB cilia are smaller and comparable in size to the chemosensory cilia. The distal segment of the AWA cilium arborizes into several small fingers. The AWB dendrite splits into a pair of cilia that becomes flattened and irregular at the distal regions. The AFD dendrite ends in a brush-like structure with many villi surrounding one cilium. BAG neurons terminate in an enlarged process distally to the cilium (Ware et al., 1975). The FLP cilium (the ending of a single cell is shown) is located at the distal end of its lateral process. Several branches extend dorsally and ventrally from the more proximal part of the dendrite. Each IL and OL dendrite terminates in a finger-like cilium. The CEP cilium widens as it ends in the cuticle. (Bottom panel) Table of the sensory cues detected by these neurons, the interneurons with which they synapse, and the behavioral response they elicit. Strain markers (strain source): AWA: odr-10::GFP (P. Sengupta), AWB: str-1::GFP (C. Bargmann/CGC), AWC: str-2::GFP (C. Bargmann/CGC), AFD: gcy8::GFP (P. Sengupta), ASI: sra-6::GFP (P. Sengupta), ADF: tph-1::GFP (S. Clark), BAG: gcy-33::GFP (L. Avery/CGC), FLP: mec-3::GFP (M. Chalfie), OLL: ser-2prom3::GFP (O. Hobert), and CEP: dat-1::GFP (S. Clark). Magnification, 600x. IL2: DiO labeling. (Image source: L. Ryder.) 3 Specific Sensilla 3.1 Amphid Sensilla The amphids are a pair of laterally located sensilla in the head that are open to the outside at the sides of the lips. They are the largest chemosensory organs of nematodes. Each amphid includes 12 sensory neurons (ADF, ADL, AFD, ASE, ASG, ASH, ASI, ASJ, ASK, AWA, AWB, AWC) with ciliated dendrites as well as one sheath (Amsh) and one socket (Amso) cell (NeuroFIG 23, NeuroFIG 24, NeuroFIG 25 and NeuroFIG 26, NeuroMOVIE 1). The sensory dendrites of 11 neurons, except those of AFD, completely penetrate the sheath-cell ending through 11 membrane-lined holes in a sieve-like fashion and then enter the sheath pouch (NeuroFIG 24). The cilia of eight of these neurons, except those of AWA, AWB and AWC, extend into the doughnut-like pore created by the socket cell and are exposed to the external medium (NeuroFIG 27). These neurons have roles in chemotaxis, mechanosensation, osmotaxis, and dauer pheromone sensation (NeuroTABLE 1) (Bargmann and Mori, 1997; Driscoll and Kaplan, 1997; Riddle and Albert, 1997; Bargmann, 2006). The cilia of odor-sensing AWA, AWB and AWC neurons invaginate back into the sheath cell and become embedded therein (NeuroFIG 24). The dendrite of the thermosensory AFD is embedded within the sheath cell throughout and terminates in a rudimentary cilium with many villi. The ending of the amphid socket cell does not form a true tube like the sheath cell, but rather, wraps around the distal portion of the cilia-filled channel and seals onto itself with an adherens junction (NeuroFIG 28). The sheath cell is connected to the amphid sensory cilia and the socket cell by adherens junctions, and the socket cell, in turn, is connected to the hypodermis by adherens junctions (NeuroFIG 24). NeuroFIG 26: Amphid neurons and amphid nerve. A. Epifluorescent image, left lateral view. Each of the bilaterally symmetric amphid nerves contains dendrites of 12 amphid neurons and the process of one amphid sheath cell. The amphid nerves travel on the lateral sides of the pharynx to the lips. The axons of the amphid neurons enter the amphid commissures on each side to reach the VNC and NR. DiI-stained animal expressing ver1::GFP marker in amphid sheath cells. Magnification, 400x. (Strain source: R. Roubin, C. Popovici, and S. Shaham.) B. Illustration of left-side amphid neurons, amphid commissure, and amphid nerve. Amphid neuron cell bodies are located posteriorly to the nerve ring, whereas amphid sheath cells are on the dorsolateral sides of the terminal bulb of the pharynx. C. TEM of right lateral region, anterior to the NR along the pharyngeal isthmus, transverse section. The amphid sheath process and the amphid neuron dendrites constitute the amphid nerve bundle, which at this level is located next to the posteriorly extending axons of the lateral labial neurons. The amphid nerve and the labial axons are sandwiched between cell bodies of NR neurons and the pharynx on the inside and the hypodermis and muscle on the outside. Bar, 1 μm. (Image source: N2U [MRC] A176-7.) D. Epifluorescent images of amphid (arrows) and IL1 (arrowheads) neurons. (Left panel) Left lateral view; (right panel) ventral view. Strain marker: Y105E8A.5::GFP. (Image source: R. Newbury. The Genome BC C. elegans gene expression consortium [McKay et al., 2004].) NeuroMOVIE 1: 3-D reconstruction of amphid and labial nerves. (Imaging by R. Newbury and Moerman lab.) NeuroFIG 27: Cells of the amphid sensilla. A. Schematic of the left lateral side of the head depicting the three types of cells of the amphid: one sheath cell, one socket cell, and a representative chemosensory neuron (ADFL) out of 12 amphid neurons. Each amphid neuron is bipolar with one sensory process (dendrite) and one presynaptic process (axon). The dendrite extends to the lip and terminates as a cilium, whereas the axon extends to the nerve ring to make synapses. B. Epifluorescent image of the right-side amphid from an animal coexpressing the T08G3.3::DsRed (ADF) and daf-6::GFP (Amsh and Amso) transgenes. View is equivalent to the boxed portion in A. The paired cilia of ADF are exposed to the outside through the sheath and socket channels. Bar, 2.5 μm. (Image reprinted, with permission, from Perens and Shaham, 2005. ©Elsevier.) (Top panel) Graphic rendition of the same region with two-pronged ADF and the large wing-like AWC cilium enclosed by the enlarged distal portion of the sheath and socket processes. (Green) Sheath cell; (pink) socket cell. C. Epifluorescent images of the amphid sheath. Images are from transgenic animals expressing the ver-1::GFP reporter gene in the sheath (arrows) and DiI stain in the amphid neurons (arrowheads). Amphid sheath cells are localized on the dorsal right and dorsal left sides of the pharynx terminal bulb (green oval, top and middle panels). A thick process extends anteriorly from each soma and travels to the lips within the amphid nerve to expand into a large sheet close to the sensilla. (Top panel) Dorsal view. (Middle panel) Left lateral view. (Bottom panel) Same as middle panel but with colors shown. Magnification, 400x. (Strain source: R. Roubin, C. Popovici, and S. Shaham.) D. DIC images of the left amphid sheath cell (left panel) and the right amphid sheath cell (right panel.) NeuroFIG 28: Structure of the amphid socket cell. A. Epifluorescent image from an animal expressing the itr-1pB::GFP reporter gene, dorsal view. Amphid socket cells are located on each side of the anterior bulb, close to the sensilla. Magnification, 400x. (Strain source: H. Baylis and N. Gower.) B. Epifluorescent image from an animal expressing the T16G1.8::GFP reporter gene, left lateral view. Amphid socket cells have simple morphologies with a small cell body, a thin process, and a small cylindrical ending (arrowhead in inset) on the lateral sides of the lips. Magnification, 600x. (Strain source: The Genome BC C. elegans gene expression consortium [McKay et al. 2004].) C. DIC, same animal as in B. Amphid socket nucleus has an epithelial appearance. It is located close to the anterior lateral hypodermal and first seam nuclei. Ablation of amphid sheath cells results in behavioral and developmental deficits, including an inability to form dauers in the presence of the pheromone (Bargmann et al., 1990; Vowels and Thomas, 1994). The amphid neurons are then unable to take up FITC in these animals. Sensory function becomes impaired following amphid sheath ablation, even after the sensory organ has formed. Although amphid neurons continue to survive in these animals, their dendritic tips show morphological abnormalities, suggesting a function for the sheath cells in maintenance of amphid ciliary properties (Perens and Shaham, 2005; Shaham, 2005). Amphid sheath cells contain large vesicles filled with matrix material that is secreted into the amphid channel (NeuroFIG 24) (Perkins et al., 1986). This electron-dense material, which fills the channel and surrounds the dendritic tips, seems to be important for dendritic structure and function. Defects in matrix production and secretion, as seen in animals with mutations in che-12 (abnormal chemotaxis), lead to impaired sensory function, poor FITC uptake into the amphid neurons, and shorter channel cilia (Perkins et al., 1986; Starich et al., 1995). Conversely, neurons modulate amphid sheath structure and function. In IFT and cilia formation mutants, matrix secretion from the sheath cells is impaired and a large number of vesicles accumulate within the sheath cells, suggesting that cilia stimulate matrix secretion (Perkins et al., 1986; Collet et al., 1998). In some of these mutants, for example daf-19, amphid channel formation by the sheath cells is also defective and the sheath cells look misshapen. Two proteins, DAF-6 and CHE-14, which are involved in the formation of tubular structures, cooperate in building the amphid channel during development (Michaux, 2000; Perens and Shaham, 2005; Shaham, 2006). Amphid channel formation occurs between the comma and 1.5-fold stages (between 330 and 430 min post-fertilization) of embryogenesis (Sulston et al., 1983). As in other epithelial cells, CHE-14 functions in apical sorting and exocytosis within sheath cells, whereas DAF-6 participates in endocytosis. Therefore, these two proteins may regulate sculpting of the apical membrane as the lumen of the sheath channel forms (Shaham, 2006).
3.2 Cephalic Sensilla Each cephalic sensillum is positioned adjacent to a counterpart outer labial quadrant (OLQ) sensillum in the lips and contains the dendrite of one of the four cephalic neurons (CEPVL, CEPVR, CEPDL, CEPDR), one sheath cell (CEPsh), and one socket cell (CEPso) (NeuroFIG 11 and NeuroFIG 29). In males, the cephalic sensilla also contain the dendrite of an additional neuron, CEM. The cilium of each CEP neuron ends embedded in the cuticle, and the CEM cilium is exposed to the outside through a hole in the cuticle. The CEP neurons, which are dopaminergic, are suggested to be texture (mechano) sensory, whereas the CEM neurons are chemosensory and required for chemotaxis to a volatile female sex pheromone of related Caenorhabditis species (Sulston et al., 1975; Sawin et al., 2000; Peden and Barr, 2005; Chasnow et al., 2007). CEP neurons, along with ADE and PDE neurons, mediate the basal slowing of the locomotion response to a bacterial lawn. The same three classes of neurons are also involved in area-restricted search (ARS) for food behavior when the worm expands its food search area by decreasing the number of acute-angled turns that it makes after it is placed on an empty plate (Hills et al., 2004). ). NeuroFIG 29: The cells of the cephalic sensilla. A. Graphic rendition depicting the cells of the left-side cephalic sensillar cells (right CEPsh cells are shown to add dimension). The four CEM neurons are only found in males. The mechanosensory CEP neurons are set in fourfold symmetry close to the NR (only left-side neurons are shown). Each CEP neuron sends a dendrite to the lips within a labial process bundle and an axon into the NR to make synaptic connections with many partners including their contralateral homologs (White et al., 1986). The four cephalic sheaths are the only bipolar sheath cells. Each extends an anterior CEP dendrite-associated process and a thin, sheet-like posterior process that envelops a quadrant of the NR. The four cephalic socket cells are localized at the posterior of the anterior bulb in fourfold symmetry. B. Epifluorescent image from an animal expressing the reporter gene hlh-17::GFP. Anterior processes (gray arrows) of the CEPsh cells (gray arrowheads) terminate in a goblet-like shape as part of the CEP sensilla. The posterior process (white arrows) surrounds part of the NR as well as the anterior extremity of the VNC. (Top animal) The right-side cells as seen from a lateral view (also note that ventral is top in this animal). (Bottom animal) Ventral view. (Insets) The sensillar endings of the sheath cells from a different level in each animal. Magnification, 400x. (Strain source: Casonya Johnson.) C. Epifluorescent image from an animal expressing the reporter gene dat-1::GFP. Cephalic neurons with anteriorly directed dendrites (thin arrows) and posteriorly directed axons (thick arrows), left lateral view. Magnification, 400x. (Strain source: S. Clark.) D. Image of the same animal as in C from a different level. Magnification, 600x. E. Epifluorescent images from an animal expressing the reporter gene hlh-17::GFP in sheath cells, left lateral view. (Top panel) DIC/GFP images merged to display the cell body positions. (Bottom panel) GFP image only. Magnification, 400x. (Strain source: C. Johnson.) The CEP sheath cells are the only bipolar glial cells serving two distinct glial functions. Each cell has both an anteriorly directed, dendrite-associated process and a posteriorly directed, lamellar process. The anterior processes travel with those of CEP neurons and CEPso cells to form a channel around the CEP neuron dendrites in the lips (NeuroFIG 30 and NeuroFIG 31). The thin, posterior processes, on the other hand, wrap the outside of the nerve ring and ventral ganglion neuropil, separating these structures from adjacent hypodermis and muscle as well as from some neuron cell bodies (NeuroFIG 32) (Ware et al., 1975; White et al., 1986). Narrow, radial extensions from the sheath cells are also found juxtaposed to a small number of synapses within the NR. It has been suggested that CEPsh cells function in assembly and morphogenesis of the NR during development by providing important substrates for early axon guidance of processes entering the NR from the posterior (Wadsworth et al., 1996). NeuroFIG 30: Structure of the cephalic and outer labial sensilla. (Left) Schematic view of longitudinal section through the CEP and OL sensilla with additional transverse schematics shown to the right. Each of the four cephalic and six outer labial sensilla are similar in their morphologies, with one ciliary neuron ending surrounded by one sheath cell and one socket cell. In each sensillum, the cilium passes through a narrow channel and terminates embedded within the cuticle. OLL neurons are shorter and smaller and end about 0.5 μm more posteriorly than OLQ cilia. In addition, it has no ciliary rootlet (Ward et al., 1975). CEP, OLQ, and OLL cilia are also connected to the cuticle by a small nubbin. The nubbin is located at the base of the distal region in CEP and OLQ cilia. In contrast, the nubbin is at the tip of the OLL cilia and distal to the supernumerary microtubules and the tubule-associated material (TAM) (inset, bottom left). In males, the cilium of a second neuron, CEM, extends through the CEP channel and cuticle to the outside. There are adherens junctions between socket cell and sheath cell, neuron and sheath cell, and hypodermis and socket cell. CEP and OLQ sensilla are positioned next to each other within the two ventral and two dorsal labia. (Inset, top left) Longitudinal TEM section through CEP and OLQ sensilla. Visible are the dark TAM within the CEP cilium as well as a nubbin anchoring the base of the distal segment of CEP cilium to the cuticle. (Image source: Hall archive.) (Right) Transverse TEMs through CEPVL and OLQVL sensilla at three different levels, from distal tip (top panel) to more proximal (bottom panel). (Top panel) Termini of cilia within the cuticle. (Middle panel) Socket cells form the distal segment of the sensillar channels. (aj) Adherens junctions. (Bottom panel) Proximal part of the channel is created by the sheath cell. Both the CEP and OL sheath cells have membraneous lamellae stacked within the cytoplasm near the sheath channels (OLQshVL lamellae are not seen in this section). Individual lamellae connect to the channel lumen. A striated rootlet (SR) is visible in the OLQVL cilium. Bar, 1 μm. (Image source: E. Hartwieg and H.R. Horvitz 1339/96 [top], 1339/96 [middle], and 1345/96 [bottom].) NeuroFIG 31: CEP, CEM and OL cilia ultrastructure. All transverse sections. A. Section through the DR lip of an adult male. The distal segments of CEP and OL cilia contain supernumerary microtubules and an amorphous dark material associated with them (TAM) that is common to many mechanocilia (Perkins et al., 1986). The CEP cilium widens as it enters the cuticle, and this distal segment is filled with numerous MTs organized around electron-dense TAM cores. In OLL cilium, TAM forms a large central aggregate around which a single layer of many MTs is seen (inset). In both types of cilia, the outermost MTs are connected to the membrane through fine attachments. The OLQ cilium contains less robust TAM at the periphery. In all three types of cilia, the distal MTs are all supernumerary singlets. They do not derive from the nine doublets nor the inner singlets of the apical ring of the transition zone, and they only exist in the distal segments. The CEM cilium is exposed to the outside through a small bump and hole in the cuticle at this level. B. Section slightly more posterior to A from the same animal. CEM and CEP cilia lie within the same channel. The chemosensory CEM cilium is ultrastructurally different from the mechanosensory CEP; it is narrow and has no TAM or supernumerary MTs, but contains 12–13 singlet MTs. C. Section from a similar level as in B from a hermaphrodite animal. There is no CEM cilium. The A and B subfibers of the MT doublets of the OLQ cilia have filled centers and appear dark. Four of the original nine doublets continue to the distal end and are connected to one another by side bridges to form a square and to the center by fine radial arms (inset). D. Section through the nubbin (N) of the CEP cilium. The OLQ nubbin is more anterior to this section (not shown). (Inset) An OLL cilium from approximately the same level of section. At this level no TAM is left and only the singlet MTs are seen in the short cilium. E. Section through the transition zone of the OLQ cilium. It contains nine doublet MTs that are connected to the membrane through Y-shaped attachments. Only four of the doublets continue in the middle and distal segments. (M) Matrix. F. Section through the transition zone of the CEP cilium. Only five of these doublets continue to the middle segments. A striated rootlet (SR) is seen in the OLQ dendrite. (M) Matrix. G. Section through the transitional fibers of the CEP cilium. H. Section proximal to the transition zone of the CEP cilium. SR continues in the OLQ dendrite, and adherens junctions are seen between the dendrite and OLQsh. The CEP dendrite contains a few vesicles and several intermediate filaments. Lamellae (arrowheads) are seen within both sheath cells. (aj) Adherens junction. Bar, 0.5 μm; applies to all panels. (Image sources: [Hall] 493-2/9103 [A] and 9105 [B]; [MRC] N2nose 3730-16 to 3731-17 [C–H].) NeuroFIG 32: Cephalic sheath cells envelop the synaptic neuropil. Schematic rendition of the morphology and neighborhoods of the CEPshVL. The structures are traced from actual TEM sections. (Top panel) Cell extensions around the NR and VNC. (Arrows with numbers) Section levels in panels 1–8. The CEPshVL cell body is anterior and ventral to the NR. The anterior process travels within the ventral labial process bundle. The thin, posterior, sheet-like process extends among the nervous tissue, hypodermis, and muscle. (Gray ovals) Nuclei. 3.3 Inner Labial Sensilla Inner labial sensilla are found in a sixfold, symmetrically arranged manner at the apex of each lip (ILDL/R, ILLL/R, ILVL/R) (NeuroFIG 33). Each of these sensilla contains two dendrites (IL1 and IL2) as well as one sheath (ILsh) and one socket (ILso) cell (NeuroFIG 34). The IL2 cilia penetrate the cuticle and are exposed to the outside, whereas each IL1 cilium terminates in an electron-dense, membrane-attached disc embedded in the cuticle approximately 0.5 μm below this opening (NeuroFIG 35) (Ward et al., 1975; Perkins et al., 1986). Unlike the amphids, inner labial socket channels are not lined with cuticle; however, an extracellular material surrounds the cilia within the socket and subcuticular channels (Ward et al., 1975). IL and OLQ socket cells express DEG/ENaC sodium channels DELM-1 and DELM-2 which are required cell-autonomously in the socket cells for mechanosensation by IL1 and OLQ, possibly by setting basal neuronal excitability (Han et al., 2013). During development, ILsh cells are suggested to guide axons entering the NR neuropil from the anterior via the six labial nerves (Wadsworth et al., 1996; Antebi et al., 1997). IL1 neurons are mechanosensory and perform head withdrawal in response to dorsal or ventral nose touch (Hart et al., 1995; Kaplan and Driscoll, 1997). From their synaptic interactions, they are also suggested to function as motor neurons and interneurons (White et al., 1986). IL2 neurons are postulated to be chemosensory (Perkins et al., 1986). Only the inner labial sensilla form distinct bumps in the lip cuticle when viewed by scanning electron micrography from the outside (see IntroFIG 4). NeuroFIG 33: Inner labial sensilla. A. Graphic rendition depicting the cells of the left-side inner labial sensilla. Axons of IL1 and IL2 neurons are omitted. Both IL1 and IL2 are sets of six ciliated neurons, and each IL sensillum contains one neuron from each set. Dendrites of IL1 and IL2 neurons run in each of the six labial process bundles. IL1 and IL2 cell bodies are located anteriorly to the NR. Posteriorly directed axons rejoin the labial process bundles and enter the NR (not shown). The socket cell and sheath cell of each labial sensillum are located more anteriorly than the neurons. The sensilla are placed at the tip of each of the six lips. B. Epifluorescent image of the left-side IL1 neurons from a transgenic animal expressing the reporter gene Y111B2A.8::GFP. (Thick arrow) Dendrite of IL1DL; (thin arrow) axon of the same neuron, lateral view. (Strain source: The Genome BC C. elegans gene expression consortium [McKay et al., 2004].) C. Epifluorescent image of right-side IL2 neurons from an animal stained with the vital dye DiO. (Thick arrow) Dendrite of IL2DR; (thin arrow) axon of the same neuron, lateral view. Bar, 20 μm. (Image source: L. Ryder.) NeuroFIG 34: Ultrastructure of an inner labial sensillum. A. Schematic of longitudinal section through an inner labial sensillum with six transverse views; anterior is at the top. The six inner labial sensilla have identical structures except for the endings of the FLP neurons that are seen associated only with the lateral labial sensilla; the BAG neuron endings terminate close to the ventral labial sensilla. Each sensillum contains one sheath cell, one socket cell, one IL1 cilium, and one IL2 cilium. The IL2 cilium protrudes outside through a hole in the cuticle and is suggested to be chemosensory. The IL1 cilium terminates in the cuticle approximately 0.5 μm below this hole and is mechanosensory. The IL1 dendrite contains a striated rootlet. There are adherens junctions (aj) between the socket cell and hypodermis, sheath and socket cell, and neuron and sheath cell. An ECM material is seen within the cuticle and socket channel. A specialized subcuticle surrounds the ending and protrudes from the lip cuticle. B. TEM, transverse section. This section is through the disc of dark material attached to the IL1 ciliary membrane at its tip. This disc is suggested to help sense the deflections of the inner labial papilla when it is compressed by contact with external objects (Ward et al., 1975; Perkins et al., 1986). Some of the MTs that originate from the transition zone reach and fuse with the disc. The IL2 transition zone, which is not as well defined as the IL1 transition zone, is about 2.5 μm from its tip (not shown). Five to seven doublet MTs originate from this zone. These doublets become singlets as they extend into the distal region. (Image source: [Hall] 493-2B/9118.) C. Transverse section through the transition zone of IL1 cilium. Nine MT doublets are seen in a ring structure with the tip of the striated rootlet (SR) becoming visible in the center. (Image source: [MRC] N2nose 3730-16.) D. Transverse section through the transitional fibers (arrowheads) in IL1 cilium. IL2 cilium is in the same channel surrounded by the sheath cell with matrix-filled, large vesicles (V). (Image source: [MRC] N2nose 3730-18.) E. Transverse section through IL2-sheath junction (arrows). IL1 dendrite contains an SR. (Image source: [MRC] N2nose 3730-20.) F. Transverse section through the transition zone of BAGR cilium and transitional fibers of FLPR cilium. (Ph) Pharynx lumen. Bar, 0.5 μm. (Image source: [MRC] N2nose 3731-4.) NeuroFIG 35: Ultrastructure of two lips. The amphid and OLL sensilla have twofold symmetry and reside in the lateral lips. CEP and OLQ sensilla have fourfold symmetry and reside in the dorsal and ventral lips. IL sensilla have sixfold symmetry and are located in all six lips. A–E. TEMs, longitudinal oblique sections. (Top right inset) Scanning electron microscopy (SEM) image indicating the approximate section levels in A–E. Bar in A, 5 μm. A. Section through the left lateral lip with the OLLL cilium ending in the cuticle. The many cilia within the left amphid channel can be seen tightly clustered. (Image source: B156 [Hall] 7793.) B. Section through the left lateral lip at the level of the amphid opening. The amphid cilia become narrower within the amphid channel at their distal ends. (Image source: B156 [Hall] 7805.) C. Section through the tip of the left dorsal lip. Seen is the electron-dense disc at the tip of DL inner labial papilla. The subcuticular termini of CEPDL and OLQDL are seen below the papilla. (Image source: B156 [Hall] 7897.) D. Section through a more dorsal level than that in C. Seen are closely neighboring OLQ and CEP cilia in the subcuticle. More proximally, the striated rootlet (arrow) of the OLQDL dendrite is visible (the small inset on the right is magnified from the same area). (Arrowhead) Adherens junction between OLQso and hypodermis. (Image source: B156 [Hall] 7896.) E. Section through the middle and distal regions of CEPDL and OLQDL sensilla. As it enters the cuticle, CEPDL widens and acquires supernumerary MTs and TAM. A nubbin is seen at the base of its distal region (arrow). (Image source: B156 [Hall] 7905.) 3.4 Outer Labial Sensilla There are six outer labial sensilla, one on each lip just posterior to the inner labial sensilla (NeuroFIG 36). Each of the outer labial sensilla has only one outer labial sensory neuron dendrite (OLQ or OLL), one sheath (OLsh) cell, and one socket (OLso) cell (NeuroFIG 30) (Ward et al., 1975; Ware et al., 1975; Perkins et al., 1986). Although the fine structures of the OLQ and OLL sensilla differ (NeuroFIG 31), these neurons are placed in the same class on the basis of similarities of positions of their cell bodies, the similarity of their arrangement in the nerve cords, and the location and structure of their sheath cells (Ward et al., 1975). Similar to inner labial sensilla, outer labial sensillar socket channels are not lined with cuticle. The four OLQ neurons are mechanosensory, but they may also function as interneurons (Hart et al., 1995; Kaplan and Driscoll, 1997). Along with IL1 neurons, they transduce signals for head withdrawal response to dorsal and ventral nose touch. Together with ASH and FLP neurons, they also mediate reversal of movement in response to head-on collision. The two OLL neurons are suggested to be mechanosensory (Perkins et al., 1986). IL and OLQ socket cells are involved in mechanosensation by these neurons as noted above. NeuroFIG 36: Cells of the outer labial sensilla. A. Schematic rendition depicting the cells of the left-side outer labial sensillar cells. The axons of the neurons are omitted. Four OLQ neurons have ciliated dendritic endings in the dorsal and ventral outer labial sensilla. Two OLL neurons have ciliated endings in the lateral outer labial sensilla. OLQ cell bodies are anterior to the NR, and OLL cell bodies are on the posterior sides of the anterior bulb of the pharynx. All have anteriorly directed dendrites that run in labial process bundles. Posteriorly directed axons from all six neurons rejoin the labial process bundles before they enter the NR and make synapses (not shown). B. Epifluorescent image of the OLL neuron pair from a transgenic animal expressing the reporter gene ser2prom3::GFP. (Arrow) Midline region in the NR where the dorsal branches of the OLL axons terminate by making GJs to one another; (arrowheads) dendrites of OLL neurons. Dorsal view. Magnification, 400x. (Strain source: O. Hobert.) C. (Top panel) Epifluorescent image of the bipolar OLLL neuron from a transgenic animal expressing the same reporter gene as in B, lateral view. Seen is the bifurcation of the OLLL axon in the NR (arrow). Both the ventral and dorsal branches make GJs to their symmetrical partners at the ventral and dorsal midlines of the NR. (Bottom panel) Same epifluorescent image is transposed over the DIC image of the head. D–F. Outer and inner labial socket cells. Epifluorescent images from transgenic animals expressing the reporter gene ITXp::GFP. Most of the OL and IL socket cell somata are grouped around the anterior region of the anterior bulb of the pharynx. The anteriorly directed sensillar processes terminate symmetrically in bulb-like endings within the six lips (arrowheads). Magnification, 400x. D. Left lateral oblique view, medial level. E. Left lateral oblique view, same animal as in D, lateral level. F. Dorsal view. (Strain source: L. Haklai-Topper and E. Peles.)
3.5 Anterior and Posterior Deirid Sensilla The ADE and PDE neurons are each bilaterally paired, dopaminergic cells. Along with the CEP neurons, they are involved in mechanical texture sensation (NeuroTABLE 1) (Sawin et al., 2000; Hills et al., 2004). Both classes have ciliated sensory endings embedded in the cuticle (Ward et al., 1975; Perkins et al., 1986). Anterior deirid sensilla are located bilaterally at the posterior of the head, positioned within the alae (NeuroFIG 37). An ADE neuron, one sheath cell (ADEsh), and one socket cell (ADEso) comprise the sensillum on each side. ADE neurons lie posteriorly and ventrally to the terminal bulb. The dorsal ADE process sends off a short branch on the side, which extends to the lateral wall and terminates as a cilium (NeuroFIG 38). The dorsal process extends into the ring neuropil and makes synapses with OLL, CEP, and FLP (White et al., 1986). Through the deirid commissures, each ADE ventral process reaches the ventral ganglion neuropil, where it synapses onto RIG and AVA neurons. NeuroFIG 37: Ultrastructure of the anterior deirid sensillum. A. SEM, left lateral view. Anterior deirid sensilla are located along the alae, at the posterior of the head, near the terminal bulb. (Inset) Left deirid papilla, magnified. (Image source: D.H. Hall and C. Marks.) B. Epifluorescent image from a transgenic animal expressing the reporter gene dat-1::GFP in ADE neurons, left lateral view. ADEso cells (pink), ADEsh cells (green), and the pharynx (transparent green) are drawn on the image to indicate the relative positions of each cell. A branch from the dorsal ADE process projects to the lateral body wall to form the cilium. Processes from the socket cell and the sheath cell are the other two components of the sensillum. The ventral process from the ADE neuron travels within the deirid commissure before entering the retrovesicular ganglion and terminates shortly after entering the ventral ganglion. C. Graphic rendition depicting the cells of the anterior deirid sensillum, transverse view, rotated 90°. The cilium of the ADE neuron, which is mechanosensory, terminates within the cuticle of the alae and is anchored to it through a nubbin. D–F. TEMs of an anterior deirid sensillum, transverse sections. Bar, 0.5 μm. D. Section through the sensillar ending. Electron-dense cytoplasmic material (TAM) is seen in the center of the cilium at its tip. (Arrowheads) Adherens junctions between the socket and seam cells. E. Section through the junction of the socket and sheath cells. (Arrowheads) Adherens junctions between socket and seam cells and the self-junction of the socket cell. F. Section through the transition zone of the ADE cilium. Nine doublets are aligned along an apical ring and are connected to the membrane through Y-shaped fibers. Three to four singlet MTs are seen inside. (Arrowheads) Adherens junctions. (Image source: [D] [MRC] N2 deirid adult 2753-18, [E] [MRC] N2 deirid adult 2753-13, [F] [Hall] B306H 2447.) NeuroFIG 38: Cells of the right anterior deirid sensillum. Low- power TEM images of the right anterior deirid, transverse views. The sensillar components are colored on the TEM images. All components lie medially to the lateral hypodermis. Sections are ordered from anterior to posterior throughout. (Ph) Pharynx. Bar, 1 μm. A. Section through the cell body of the ADE socket cell. Also seen is the commissural (ventrally directed) process of ADER. (Image source: N2U [MRC] 217-19.) B. Section through the processes of the socket and sheath cells and the ADER cilium as they travel together laterally. (Image source: N2U [MRC] 217-24.) C. Section through the sensillar processes as they reach the outermost body wall. (Image source: N2U [MRC] 22017.) D. Section through the ADER sensillum where sheath surrounds the cilium. (Image source: N2U [MRC] 221-6.) E. Section through the cell body of the ADER neuron located on the lateral side of the terminal bulb of the pharynx. (Image source: N2U [MRC] 234-10.) F. Section through the cell body of the ADEshR, which is located more posteriorly near the pharyngeal–intestinal valve. (Image source: N2U [MRC] 250-10.) Unlike anterior deirid sensilla, posterior deirid sensilla are dorsal to the alae and are located halfway between the vulva and tail, next to dorsal body wall muscle quadrants on each side (NeuroFIG 39). Each posterior deirid sensillum consists of one PDE neuron, one sheath cell (PDEsh), and one socket cell (PDEso) that are born post-embryonically in the L2 stage from the V5 lineage (see Epithelial system). The ventral processes of the PDE neurons extend in a single fascicle with the processes of PVD neurons on each side. They cross the lateral nerves and subventral cords and pass between the hypodermis and ventral body muscles before reaching the VNC (Hedgecock et al., 1990). They bifurcate in the VNC, and both the anterior and posterior branches run in close apposition to their contralateral homologs within the VNC and make GJs to one another. They receive synapses from PVM and PLM and send output onto DVA and AVK neurons (White et al., 1986). NeuroFIG 39: Posterior deirid sensilla. A. DIC micrograph of an adult hermaphrodite with a clr-1 mutation, lateral view. Posterior deirids lie halfway between the vulva and tail on both sides of the nematode body. Each sensillum is composed of the PDE cilium, one socket cell, and one sheath cell and is located dorsally to the alae within the lateral hypodermal ridge. The cells of each posterior deirid sensillum derive from the same blast cell, V5p, and lie close to one another (see Epithelial system - Hypodermis ). A short process from the sheath and another process from the socket cell surround the cilium of the mechanosensory PDE neuron, which terminates within the cuticle as a TAM-filled ending (see IntroFIG 4B). Similar to the ADE cilium, the PDE cilium is anchored to the cuticle through a nubbin located at its base (not shown). Bar, 10 μm. (Image reprinted, with permission, from Hedgecock et al., 1990.) B. Epifluorescent image from a transgenic animal expressing the reporter gene dat-1::GFP, left lateral view. The bipolar PDE neuron extends a dorsal cilium and also sends a commissural process (arrowhead) to the VNC, which bifurcates within the VNC and grows in anterior and posterior directions. (Strain source: S. Clark.) 3.6 Phasmid Sensilla The phasmids are located at the lateral sides of the tail, behind the rectum. They are composed of one sheath cell, two socket cells, and the ciliated dendrites of PHA, PHB, and PQR neurons (only on the left side) (NeuroFIG 40). The phasmids are similar in structure to amphid sensilla, but smaller. The cilia of PHA and PHB neurons extend into the external medium through the hole created by socket cells on both sides, whereas the tip of the PQR dendrite is wrapped within PHso2L (NeuroFIG 41) (Hall, 1977). Cell bodies of the phasmid neurons are located in the lumbar ganglia. Growth of the phasmid neuron axons occurs in two separable stages during embryogenesis; the first stage involves growth into the PAG neuropil through the lumbar commissures pioneered and organized by PVQs and PVT, respectively (Hedgecock et al., 1985). In the second stage, the phasmid axons grow along the posterior VNC and make synapses. No synapses are made within the commissures, and synapses formed in PAG neuropil by lumbar processes, including the phasmid axons, are nearly all dyadic. The PHAs and PHBs form chemical synapses and GJs with their contralateral homologs. Additionally, thePHBs form dyadic synapses onto AVA and PVC interneurons, and PHAs form chemical synapses onto PHB and PVQ neurons (Hall and Russell, 1991). PHA and PHB neurons function in modulation of chemorepulsion behavior in worms, whereas PQR is suggested to be a mechanosensor (Hilliard et al., 2002; Sengupta, 2002). NeuroFIG 40: Sensilla of the tail tip. The phasmids are similar in organization to amphid sensilla, but are smaller. They are located at the lateral sides of the tail and are composed of the ciliated dendrites of PHA, PHB, and, on the left side, PQR neurons as well as one sheath cell and two socket cells. Additional sensory cells extend dendrites into the extreme tail tip, but they lack cilia. A. Epifluorescent image of a transgenic animal expressing the reporter gene pida-1::GFP, left lateral aspect. The sensillar PHA, PHB neurons, and the PHC neuron, which is not part of the phasmid, are located within the lumbar ganglia on both sides of the tail behind the rectum. (Small arrow) Phasmid openings; (arrowhead) long posterior process of the PHC neuron that extends into the tail tip. All three neurons send anteriorly directed axons (thin arrow) into the PAG neuropil via lumbar commissures. Magnification, 400x. (Strain Source: T. Zahn and J. Hutton.) B. Epifluorescent image of a transgenic animal expressing the same reporter gene as in A, ventral view. The axons of the PHC and the phasmid neurons PHA and PHB terminate within the PAG neuropil (thin arrow) where they make synapses. The dendrites of PHA and PHB extend into the phasmid sensilla located on the lateral sides of the tail (arrows) in a symmetric fashion. These neurons modulate chemorepulsion behavior (Hilliard et al., 2002). (Arrowheads) Tail tip processes from PHC neurons, which are suggested to be proprioceptive. Magnification, 400x. C. DIC image of the same animal as in B transposed over the epifluorescent image to indicate cell positions. D. Epifluorescent image from a transgenic animal expressing the reporter gene ZC53.7::GFP in the postembryonic PQR neuron, left lateral view. The PQR cilium is part of the left phasmid. The PQR axon extends into the PAG via the left lumbar commissure. (Image source: R. Newbury. The Genome BC C. elegans gene expression consortium [McKay et al., 2004].) E. SEM of an animal from the left lateral aspect showing the left phasmid sensillar opening (arrow). (Image source: D.H. Hall and C. Marks.) NeuroFIG 41A-I: Structure of the phasmid sensilla. (Based on Hall, 1977; Sulston et al., 1980.) In the schematic illustrations, dark lines indicate adherens junctions. A&B. Larval development of the phasmid sensillum. A. Five hours after hatching, the T seam cell functions as the phasmid socket. B. Twenty-two hours after hatching, late-L2 stage. Phasmid structure is still the same between sexes. T-cell daughters T paa (PHso1) and T pap (PHso2) perform the socket cell function. T paa wraps around the channel and is attached to the sheath and T pap by adherens junctions. T pap is attached to the seam and hypodermis by adherens junctions. C–D. Epifluorescent images from transgenic animals expressing the reporter gene ver-1::GFP in the phasmid sheath cells, left lateral oblique views. DiI-labeled phasmid neurons are also visible in C. Original magnification, 400x. (Strain source: S. Shaham, R. Roubin, and C. Popovici.) E. DIC image from a transgenic animal expressing the reporter gene T16G1.8::GFP, left lateral view. The two small phasmid socket cell bodies are located slightly dorsally and close to the phasmid sensillum. F. Same animal, epifluorescent image. Each phasmid socket cells wraps around itself to create a tubular channel (arrowhead) containing the cilia of PHA and PHB neurons. Original magnification, 400x. (Strain source: The Genome BC C. elegans gene expression consortium [McKay et al. 2004].) G. DIC image of phasmid socket and sheath cells in the tail. Lateral view. H. Amphid sensillum in the adult hermaphrodite. PHso2 wraps around PHso1, which encircles the channel. I. Adult male. The socket function is performed by PHso2 while PHso1 transdifferentiates into PHD neuron at L4 (Molina-Garcia et al., submitted, 2019.) NeuroFIG 41J: Structure of the phasmid sensilla. I. Left phasmid sensillum in the adult hermaphrodite. Also seen are processes of nonsensillar PHC and PLM neurons. (Top left panel) Schematic illustration indicating the section levels for insets a–f (all transverse-section TEMs, viewed from the caudal). a. Section through extreme tail tip with PHCL/R processes terminating embedded in hyp 10. Bar, 0.5 μm. b. Left phasmid opening with PHA and PHB cilia exposed to the outside. c. PHA and PHB cilia within the socket channel. d. Transition zones of PHA and PHB cilia with nine doublet MTs on the outside and singlet MTs on the inside. At this level, the channel is formed by the sheath cell. e. PQR ciliary ending within PHso2L. f. Transition zone of the PQR cilium. (Image source: [Hall] B136.) At the L1 stage, a seam cell, T, performs phasmid socket cell function and is attached to the sheath cell and syncytial hypodermis by adherens junctions in both sexes. At the L2 stage, when phasmid structure is still indistinguishable between sexes, the T-cell daughters PHso1 and PHso2 perform the socket cell function. PHso1 wraps around the tip of the neuronal dendrites and is connected to PHsh and PHso2, but not to the hypodermis, by adherens junctions. PHso2, on the other hand, is connected to the hypodermis and PHso1, but not to PHsh. Later, male and hermaphrodite phasmids differ in their composition. In the adult male, PHso2 functions as a true socket cell, whereas PHso1 protrudes into the sheath and may contain up to two basal bodies, although it does not display any other characteristics of neurons. In the adult hermaphrodite, on the other hand, PHso1 is the main socket cell and PHso2 has a thin wrapping around it. Phasmid sheath cells extend short processes posteriorly into the tail tip to form a protective channel for PHA and PHB cilia near the phasmid openings. 4 Other Sensory Neurons of the Tail The tail tip of the hermaphrodite contains other sensory neurons that are not associated with any sheath or socket cells. These neurons are suggested to transduce mechanical signals, for example, during bending of the tail tip (Hall, 1977; Hall and Russell, 1991). Only one of these neurons, PVR, is ciliated. The PVR cilium is buried in the tail tip hypodermis along the postanal ridge. PHCs are bilateral post-embryonic neurons, processes of which do not enter the phasmid sensilla. Long dendritic extensions of the PHC neurons also traverse the tail tip hypodermis, ending finally within a narrow tube of cuticle in the posterior tail whip (NeuroFIG 41). PLN, ALN, and PDB neurons also extend processes into the tail tip that may function as stretch receptors. 5 List of Neuronal Support Cells 1. Sheath Cells ADEshL ADEshR AMshL AMshR CEPshDL CEPshDR CEPshVL CEPshVR ILshDL ILshDR ILshL ILshR ILshVL ILshVR OLLshL OLLshR OLQshDL OLQshDR OLQshVL OLQshVR PDEshL PDEshR PHshL PHshR 2.Socket cells ADEsoL ADEsoR AMsoL AMsoR CEPsoDL CEPsoDR CEPsoVL CEPsoVR ILsoDL ILsoDR ILsoL ILsoR ILsoVL ILsoVR OLLsoL OLLsoR OLQsoDL OLQsoDR OLQsoVL OLQsoVR PDEsoL PDEsoR PHso1L PHso2L PHso1R PHso2R TL (postembryonic blast cell; functions as phasmid socket in L1)- see Epithelial System-Seam Cells TR (postembryonic blast cell; functions as phasmid socket in L1)- see Epithelial System-Seam Cells 6 References Albert, P.S., Brown, S.J. and Riddle, D.L. 1981. Sensory control of dauer larva formation in C. elegans. J. Comp. Neurol. 198: 435-451. Abstract Antebi, A., Norris, C.R., Hedgecock, E.M. and Garriga, G. 1997. Cell and growth cone migrations. In C. elegans II (ed. D.L. Riddle et al.), pp. 583–609. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Bargmann, C.I. 2006. Chemosensation in C. elegans. In WormBook (ed. The C. elegans Research Community), WormBook, doi/10.1895/wormbook.1.123.1. Article Bargmann, C.I. and Mori, I. 1997. Chemotaxis and thermotaxis. In C. elegans II (ed. D.L. Riddle et al.), pp. 717–737. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Bargmann, C.I., Thomas, J.H. and Horvitz, H.R. 1990. Chemosensory cell function in the behavior and development of Caenorhabditis elegans. Cold Spring Harbor Symp. Quant. Biol. 55: 529-538. Abstract Barr, M.M. 2005. Caenorhabditis elegans as a model to study renal development and disease: sexy cilia. J. Am. Soc. Nephrol. 16: 305–312. Article Bird, A.F. and Bird. J. 1991. The structure of nematodes. Academic Press, California. Blacque, O.E., Reardon, M.J., Li,C., McCarthy, J., Mahjoub, M.R., Ansley, S.J. et al. 2004. Loss of C. elegans BBS-7 and BBS-8 protein function results in cilia defects and compromised intraflagellar transport. Genes Dev. 18: 1630–1642. Article Blacque, O.E., Perens, E.A., Boroevich, K.A., Inglis, P.N., Chunmel, L., Warner, A. et al. 2005. Functional genomics of the cilium, a sensory organelle. Curr. Biol. 15: 935-941. Article Bossinger, O. and Bachmann, A. 2004. Ciliogenesis: polarity proteins on the move. Curr. Biol. 14: R844–R846. Article Chalfie, M. and Thomson, J.N. 1982. Structural and functional diversity in the neuronal microtubules of Caenorhabditis elegans. J. Cell Biol. 93: 15-23. Article Chasnov, J.R., So, W.K., Chan, C.M. and Chow, K.L. 2007. The species-, sex-, and stage-specificity of a Caenorhabditis sex pheromone. Proc. Nat. Acad. Sci. 104: 6730–6735. Article Collet, J., Spike, C.A., Lundquist, E.A., Shaw, J.E. and Herman, R.K. 1998. Analysis of osm-6, a gene that affects sensory cilium structure and sensory neuron function in Caenorhabditis elegans. Genetics 148: 187-200. Article Doroquez, D.B., Berciu, C., Anderson, J.R., Sengupta, P. and Nicastro, D. A high-resolution morphological and ultrastructural map of anterior sensory cilia and glia in Caenorhabditis elegans. eLife 2014; 3:e01948. Article Driscoll, M. and Kaplan, J. 1997. Mechanotransduction. In C. elegans II (ed. D.L. Riddle et al.), pp. 645–677. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Evans, J.E., Snow, J.J., Gunnarson, A.L., Ou, G. and Scholey, J.M. 2006. Functional modulation of IFT kinesins extends the sensory repertoire of ciliated neurons in Caenorhabditis elegans. J. Cell Biol. 172: 663–669. Article Fujiwara, M., Ishihara, T. and Katsura, I. 1999. A novel WD40 protein, CHE-2, acts cell-autonomously in the formation of C. elegans sensory cilia. Development 126: 4839-4848. Article Hall, D.H. 1977. “The posterior nervous system of the nematode Caenorhabditis elegans.” Ph.D. thesis. California Institute of Technology, Pasadena. Hall, D.H. and Russell, G.J. 1991. The posterior nervous system of the nematode Caenorhabditis elegans: Serial reconstruction of identified neurons and complete pattern of synaptic interactions. J. Neurosci. 11: 1-22. Article Han, L., Wang, Y., Sangaletti, R., D'Urso, G., Lu, Y., Shaham, S. and Bianchi, L. 2013. Two novel DEG/ENaC channel subsunits expressed in glia are needed for nose-touch sensitivity in C. elegans. J. Neurosci. 33:936-949. Article Hart, A.C., Sims, S. and Kaplan, J.M. 1995. Synaptic code for sensory modalities revealed by C. elegans GLR-1 glutamate receptor. Nature 378: 82-85. Abstract Hedgecock, E.M., Culotti, J.G., Thomson, J.N. and Perkins, L. A. 1985. Axonal guidance mutants of Caenorhabditis elegans identified by filling sensory neurons with fluorescein dyes. Dev. Biol. 111: 158-170. Abstract Hedgecock, E.M., Culotti, J.G. and Hall, D.H. 1990. The unc-5, unc-6, and unc-40 genes guide circumferential migrations of pioneer axons and mesodermal cells on the epidermis in C. elegans. Neuron 4: 61-85. Abstract Hilliard, M., Bargmann, C.I. and Bazzicalupo, P. 2002. C. elegans responds to chemical repellents by integrating sensory inputs from the head and the tail. Curr. Biol. 12: 730-734. Article Hills, T., Brockie, P.J., and Maricq, A.V. 2004. Dopamine and glutamate control area-restricted search behavior in Caenorhabditis elegans. J. Neurosci. 24: 1217–1225. Article Inglis, P.N., Ou G., Leroux M.R. and Scholey J.M. 2007. The sensory cilia of Caenorhabditis elegans. In WormBook (ed. The C. elegans Research Community), WormBook, doi/10.1895/wormbook.1.126.2. Article Lewis, J.A. and Hodgkin, J.A. 1977. Specific neuroanatomical changes in chemosensory mutants of the nematode C. elegans. J. Comp. Neurol. 172: 489-510. Abstract Li, J.B., Gerdes, J.M., Haycraft, C.J., Fan, Y., Teslovich, T.M., May-Simer, H., Li, H., Blacque, O.E., Li, L., Leitch, C.C., Lewis, R.A., Green, J.S., Parfrey, P.S., Leroux, M.R., Davidson, W.S., Beales, P.L., Guay-Woodford, L.M., Yoder, B.K., Stormo, G.D., Katsanis, N. and Dutcher, S.K. 2004. Comparative genomics identifies a flagellar and basal body proteome that includes the BBS5 human disease gene. Cell 117: 541–552. Article McKay, S.J., Johnsen, R., Khattra, J., Asano, J., Baillie, D.L., Chan, S., Dube, N., Fang, L., Goszczynski, B., Ha, K., Halfnight, E., Hollebakken, R., Huang, P., Hung, K., Jensen, V., Jones, S.J.M., Kai, H., Li D., Mah, A., Marra, M., McGhee, J., Newbury, R., Pouzyrev, A., Riddle, D.R., Sonnhammer, E., Tian, H., Tu, D., Tyson, J., Warner, A., Wong, K., Zhao, Z. and Moerman, D.G. 2004. Gene expression profiling of cells, tissues, and developmental stages of the nematode C. elegans. Cold Spring Harbor Symp. Quant. Biol. 68: 159-169. Abstract Michaux, G., Gansmuller, A., Hindelang, C. and Labouesse, M. 2000. CHE-14, a protein with a sterol-sensing domain, is required for apical sorting in C. elegans ectodermal epithelial cells. Curr. Biol. 10:1098-1107. Article Molina-Garcia, L., Kim, B., Cook, S.J., Bonnington, R., O'shea, J.M., Sammut, M., Gilbert, S.P.R., Elliott, D.J., Hall, D.H., Emmons, S.W., Barrios, A. and Poole, R.J. 2019. A direct gli-to-neuron natural transdifferentiation ensures nimble sensory-motor coordination of male mating behaviour. submitted. Article Ou, G., O.E. Blacque, J.J. Snow, M.R. Leroux and J.M. Scholey. 2005. Functional coordination of intraflagellar transport motors. Nature 436: 583–587. Abstract Qin, H., Rosenbaum, J.L. and Barr, M.M. 2001. An autosomal recessive polycystic kidney disease gene homolog is involved in intraflagellar transport in C. elegans ciliated sensory neurons. Curr. Biol. 11: 457-461. Article Peden, E.M. and Barr, M.M. 2005. The KLP-6 Kinesin Is Required for Male Mating Behaviors and Polycystin Localization in Caenorhabditis elegans. Curr. Biol. 15: 394-404. Article Perens, E. and Shaham, S. 2005. C. elegans daf‐6 encodes a Patched-related protein required for lumen formation. Dev. Cell. 8: 893–906. Article Perkins, L.A , Hedgecock, E.M., Thomson, J.N. and Culotti J.G. 1986. Mutant sensory cilia in the nematode Caenorhabditis elegans. Dev. Biol. 117: 456–487. Abstract Riddle, D.L. and Albert, P.S. 1997. Genetic and environmental regulation of dauer larva development. In C. elegans II (ed. D.L. Riddle et al.), pp. 739-768. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Sawin, E.R., Ranganathan, R. and Horvitz, H.R. 2000. C. elegans locomotory rate is modulated by the environment through a dopaminergic pathway and by experience through a serotonergic pathway. Neuron 26: 619-631. Article Sengupta, P. 2002. Chemosensation: tasting with the tail. Curr. Biol. 12: R386-R388. Article Shaham, S. 2005. Glia–Neuron interactions in nervous system function and development. Curr. Top. Dev. Biol. 69: 39-66. Abstract Shaham, S. 2006. Glia–neuron interactions in the nervous system of Caenorhabditis elegans. Curr. Op. Neurobiol. 16: 522–528. Abstract Sloboda, R.D. 2002. A healthy understanding of intraflagellar transport. Cell Motil. Cyto. 52: 1–8. Abstract Starich, T.A., Herman, R.K., Kari, C.K., Yeh, W.H., Schackwitz, W.S., Schuyler, M.W., Collet, J., Thomas, J.H. and Riddle, D.L. 1995. Mutations affecting the chemosensory neurons of Caenorhabditis elegans. Genetics 139: 171–188. Article Sulston, J.E. and Horvitz, H.R. 1977. Post-embryonic cell lineages of the nematode Caenorhabditis elegans. Dev. Biol. 56: 110-156. Article Sulston, J., Dew, M. and Brenner, S. 1975. Dopaminergic neurons in the nematode Caenorhabditis elegans. J. Comp. Neurol. 163: 215–226. Abstract Sulston, J.E., Albertson, D.G. and Thomson, J.N. 1980. The Caenorhabditis elegans male: postembryonic development of nongonadal structures. Dev Biol. 78: 542-576. Article Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983. The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev. Biol. 100: 64-119. Article Swoboda, P., Adler, H.T., and Thomas J H. 2000. The RFX-type transcription factor DAF-19 regulates sensory neuron cilium formation in C. elegans. Mol. Cell 5: 411–421. Article Vowels, J.J. and Thomas, J.H. 1994. Multiple chemosensory defects in daf-11 and daf-21 mutants of Caenorhabditis elegans. Genetics 138: 303–316. Article Wadsworth, W.G., Bhatt, H. and Hedgecock, E.M. 1996. Neuroglia and pioneer neurons express UNC-6 to provide global and local netrin cues for guiding migrations in C. elegans. Neuron 16: 35-46. Article Ward, S. 1973. Chemotaxis by the nematode Caenorhabditis elegans: Identification of attractants and analysis of the response by use of mutants. Proc. Natl. Acad. Sci. 70: 817-821. Article Ward, S., Thomson, J., White, J. and Brenner, S. 1975. Electron microscopical reconstruction of the anterior sensory anatomy of the nematode C. elegans. J. Comp. Neurol. 160: 313-337. Article Ware, R.W., Crossland, K., Russell, R.L. and Clark, D.V. 1975. The nerve ring of the nematode C. elegans: Sensory input and motor output. J. Comp. Neurol. 162: 71-110. Article White J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1986. The structure of the nervous system of the nematode C. elegans. Philos. Trans. R. Soc. Lond. Series B. Biol. Sci. 314: 1-340. Article
This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2010. Nervous system, neuronal support cells. In WormAtlas. doi:10.3908/wormatlas.1.19 Edited for the web by Laura A. Herndon. Last revision: June 6, 2012.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |